/*
 * Created by sweetbread
 * Copyright (c) 2025. All rights reserved.
 */

package ru.risdeveau.geotracker

import io.ktor.client.*
import io.ktor.client.engine.okhttp.OkHttp
import io.ktor.client.plugins.logging.*
import io.ktor.client.request.get
import io.ktor.client.request.post
import io.ktor.client.request.setBody
import io.ktor.http.ContentType
import io.ktor.http.HttpStatusCode
import io.ktor.http.contentType
import org.json.JSONObject

val client = HttpClient(OkHttp) {
    install(Logging) {
        logger = Logger.ANDROID
        level = LogLevel.ALL
    }
}

data class GeoData(
    val ln: Double,
    val lt: Double,
    val nick: String
)


/**
 * Validate [baseurl] and check accessibility to a server
 * @return true if baseurl is valid
 */
suspend fun health(baseurl: String): Boolean {
    try {
        val r = client.get("$baseurl/health")
        return r.status == HttpStatusCode.OK
    } catch (_: Exception) { return false }
}

/**
 * Send data to a server
 * @return true if sent successfully
 */
suspend fun sendGeo(baseurl: String = SettingsPreferences.url, data: GeoData): Boolean {
    try {
        val json = JSONObject()
        json.put("lon", data.ln)
        json.put("lat", data.lt)
        json.put("user_name", data.nick)

        client.post("$baseurl/api/app") {
            contentType(ContentType.Application.Json)
            setBody(json.toString(2))
        }
        return true
    } catch (e: Exception) {
        println("Error: ${e.message}")
        return false
    }
}