package ru.risdeveau.geotracker

import android.annotation.SuppressLint
import android.content.Context
import android.content.Context.LOCATION_SERVICE
import android.content.pm.PackageManager
import android.location.Location
import android.location.LocationListener
import android.location.LocationManager
import android.os.Bundle
import android.os.Looper
import android.util.Log
import androidx.core.content.ContextCompat

class LocationTracker(
    private val context: Context,
    private val onLocationUpdate: (Location) -> Unit
) : LocationListener {

    private val locationManager =
        context.getSystemService(LOCATION_SERVICE) as LocationManager

    @SuppressLint("MissingPermission")
    fun startTracking(interval: Long = 5000, minDistance: Float = 0f) {
        Log.d("Tracker", "perms: ${hasPermissions()}")
        if (!hasPermissions()) return

        locationManager.requestLocationUpdates(
            LocationManager.GPS_PROVIDER,
            interval,
            minDistance,
            this,
            Looper.getMainLooper()
        )

        locationManager.getLastKnownLocation(LocationManager.GPS_PROVIDER)?.let {
            onLocationUpdate(it)
        }
    }

    fun stopTracking() {
        locationManager.removeUpdates(this)
    }

    override fun onLocationChanged(location: Location) {
        onLocationUpdate(location)
    }

    override fun onStatusChanged(provider: String?, status: Int, extras: Bundle?) {}
    override fun onProviderEnabled(provider: String) {}
    override fun onProviderDisabled(provider: String) {}

    private fun hasPermissions(): Boolean {
        return ContextCompat.checkSelfPermission(
            context,
            android.Manifest.permission.ACCESS_FINE_LOCATION
        ) == PackageManager.PERMISSION_GRANTED || ContextCompat.checkSelfPermission(
            context,
            android.Manifest.permission.ACCESS_COARSE_LOCATION
        ) == PackageManager.PERMISSION_GRANTED
    }
}